@@ -26,9 +26,10 @@ from pyams_utils.adapter import adapter_config
 from pyams_viewlet.manager import TemplateBasedViewletManager, WeightOrderedViewletManager, \
     viewletmanager_config
 from pyams_viewlet.viewlet import EmptyContentProvider, Viewlet, viewlet_config
-from pyams_zmi.interfaces import IAdminLayer, IAdminView, IPageTitle
+from pyams_zmi.interfaces import IAdminLayer, IPageTitle
 from pyams_zmi.interfaces.configuration import IZMIConfiguration
 from pyams_zmi.interfaces.viewlet import IPageHeaderViewletManager
+from pyams_zmi.utils import get_object_label
 
 
 __docformat__ = 'restructuredtext'
@@ -74,9 +75,28 @@ class ContentHeaderViewlet(Viewlet):
         return super().render()
 
 
-@adapter_config(required=(Interface, IAdminLayer, IAdminView),
+def get_admin_view_title(context, request, view, label=None):
+    """Shared tool view title getter"""
+    translate = request.localizer.translate
+    object_label = get_object_label(context, request, view)
+    if label is None:
+        label = getattr(view, 'header_label', None)
+    if not label:
+        return object_label
+    return f'{object_label} <small><small>' \
+           f' <i class="px-2 fas fa-chevron-right"></i> ' \
+           f'{translate(label)}</small></small>'
+
+
+@adapter_config(required=(Interface, IAdminLayer, Interface),
                 provides=IPageTitle)
-def admin_view_title_adapter(context, request, view):  # pylint: disable=unused-argument
-    """Admin view default title adapter"""
-    configuration = IZMIConfiguration(request.root)
-    return configuration.site_name
+def admin_view_title(context, request, view):
+    """Base admin view title adapter"""
+    return get_admin_view_title(context, request, view)
+
+
+@adapter_config(required=(Interface, IAdminLayer, IModalPage),
+                provides=IPageTitle)
+def get_modal_admin_view_title(context, request, view):
+    """Modal admin view title adapter"""
+    return get_object_label(request.root, request, view)
